==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/docking/translations/docking_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Oznamovací oblast panelu</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Start docked</source>
        <translation>Spustit ukotvení v panelu</translation>
    </message>
    <message>
        <source>Show tooltip in tray</source>
        <translation>Ukázat v oznamovací oblasti panelu radu k nástroji</translation>
    </message>
    <message>
        <source>New message tray icon</source>
        <translation>Ikona v oznamovací oblast panelu pro novou zprávu</translation>
    </message>
    <message>
        <source>Blinking envelope</source>
        <translation>Blikající obálka</translation>
    </message>
    <message>
        <source>Static envelope</source>
        <translation>Statická obálka</translation>
    </message>
    <message>
        <source>Animated envelope</source>
        <translation>Kreslená obálka</translation>
    </message>
</context>
<context>
    <name>DockingManager</name>
    <message>
        <source>Current status:
%1</source>
        <translation>Současný stav:
%1</translation>
    </message>
    <message>
        <source>

Description:
%2</source>
        <translation>

Popis:
%2</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Ukončit Kadu</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/docking/translations/docking_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Oznamovací oblast panelu</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Start docked</source>
        <translation>Spustit ukotvení v panelu</translation>
    </message>
    <message>
        <source>Show tooltip in tray</source>
        <translation>Ukázat v oznamovací oblasti panelu radu k nástroji</translation>
    </message>
    <message>
        <source>New chat tray icon</source>
        <translation>Ikona v panelu pro nový rozhovor</translation>
    </message>
    <message>
        <source>Blinking Envelope</source>
        <translation>Blikající obálka</translation>
    </message>
    <message>
        <source>Static Envelope</source>
        <translation>Nehybná obálka</translation>
    </message>
    <message>
        <source>Animated Envelope</source>
        <translation>Pohybující se obálka</translation>
    </message>
</context>
<context>
    <name>DockingManager</name>
    <message>
        <source>Current status:
%1</source>
        <translation>Současný stav:
%1</translation>
    </message>
    <message>
        <source>

Description:
%2</source>
        <translation>

Popis:
%2</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Obnovit</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Zmenšit</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Ukončit Kadu</translation>
    </message>
</context>
</TS>
